
.. DO NOT EDIT.
.. THIS FILE WAS AUTOMATICALLY GENERATED BY SPHINX-GALLERY.
.. TO MAKE CHANGES, EDIT THE SOURCE PYTHON FILE:
.. "source/auto_examples/plot_contour.py"
.. LINE NUMBERS ARE GIVEN BELOW.

.. only:: html

    .. note::
        :class: sphx-glr-download-link-note

        Click :ref:`here <sphx_glr_download_source_auto_examples_plot_contour.py>`
        to download the full example code

.. rst-class:: sphx-glr-example-title

.. _sphx_glr_source_auto_examples_plot_contour.py:


=======================================
Example for plotting up a contour plot
=======================================

This is an example of how to prepare
and plot data for a contour plot

.. GENERATED FROM PYTHON SOURCE LINES 10-37



.. image:: /source/auto_examples/images/sphx_glr_plot_contour_001.png
    :alt: plot contour
    :class: sphx-glr-single-img


.. rst-class:: sphx-glr-script-out

 Out:

 .. code-block:: none

    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(






|

.. code-block:: default


    import act
    import glob
    import matplotlib.pyplot as plt

    files = glob.glob(act.tests.sample_files.EXAMPLE_MET_CONTOUR)
    time = '2019-05-08T04:00:00.000000000'
    data = {}
    fields = {}
    wind_fields = {}
    station_fields = {}
    for f in files:
        obj = act.io.armfiles.read_netcdf(f)
        data.update({f: obj})
        fields.update({f: ['lon', 'lat', 'temp_mean']})
        wind_fields.update({f: ['lon', 'lat',
                                'wspd_vec_mean', 'wdir_vec_mean']})
        station_fields.update({f: ['lon', 'lat', 'temp_mean',
                                   'atmos_pressure', 'vapor_pressure_mean',
                                   'rh_mean']})

    display = act.plotting.ContourDisplay(data, figsize=(8, 8))
    display.create_contour(fields=fields, time=time, levels=50)
    display.plot_vectors_from_spd_dir(fields=wind_fields, time=time, mesh=True,
                                      grid_delta=(0.1, 0.1))
    display.plot_station(fields=station_fields, time=time, markersize=7, color='red')
    plt.show()


.. rst-class:: sphx-glr-timing

   **Total running time of the script:** ( 0 minutes  1.208 seconds)


.. _sphx_glr_download_source_auto_examples_plot_contour.py:


.. only :: html

 .. container:: sphx-glr-footer
    :class: sphx-glr-footer-example



  .. container:: sphx-glr-download sphx-glr-download-python

     :download:`Download Python source code: plot_contour.py <plot_contour.py>`



  .. container:: sphx-glr-download sphx-glr-download-jupyter

     :download:`Download Jupyter notebook: plot_contour.ipynb <plot_contour.ipynb>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
